
from django import forms

from captcha.fields import ReCaptchaField

from feedback.models import Feedback


class FeedbackForm(forms.ModelForm):

    captcha = ReCaptchaField()

    class Meta:
        model = Feedback
        fields = ['name', 'mobile', 'email', 'subject', 'text']




from django.contrib import admin

from feedback.models import Feedback


@admin.register(Feedback)
class FeedbackAdmin(admin.ModelAdmin):

    list_display = [
        'subject', 'id', 'user', 'name', 'mobile', 'email', 'date_created'
    ]

    search_fields = ['name', 'subject', 'mobile', 'email', 'text']

    fieldsets = (
        (None, {
            'fields': (
                'user',
                ('subject', 'name', ),
                ('mobile', 'email', ),
                'text',
            )
        }),
    )




from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _


class Feedback(models.Model):

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        verbose_name=_('User'),
        blank=True,
        null=True,
        on_delete=models.SET_NULL)

    subject = models.CharField(_("Subject"), max_length=255)

    name = models.CharField(_("Name"), max_length=255, blank=True)

    mobile = models.CharField(_("Mobile"), max_length=255, blank=True)

    email = models.EmailField(_("Email"), max_length=255, blank=True)

    date_created = models.DateTimeField(
        _('Date created'), auto_now_add=True, editable=False)

    text = models.TextField(_('Message text'), max_length=4096)

    def __str__(self):
        return self.subject

    class Meta:
        verbose_name = _('Feedback message')
        verbose_name_plural = _('Feedback messages')




from django import template


register = template.Library()


@register.inclusion_tag(
    'feedback/form-js.html',
    takes_context=True,
    name='feedback_form_js')
def render_feedback_form_js(context):
    return context


@register.inclusion_tag(
    'feedback/modal-js.html',
    takes_context=True,
    name='feedback_modal_js')
def render_feedback_modal_js(context):
    return context



# Generated by Django 2.0.7 on 2019-12-20 07:13

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Feedback',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=255, verbose_name='Subject')),
                ('name', models.CharField(blank=True, max_length=255, verbose_name='Name')),
                ('mobile', models.CharField(blank=True, max_length=255, verbose_name='Mobile')),
                ('email', models.EmailField(blank=True, max_length=255, verbose_name='Email')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('text', models.TextField(max_length=4096, verbose_name='Message text')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Feedback message',
                'verbose_name_plural': 'Feedback messages',
            },
        ),
    ]




from django.conf import settings
from django.apps import apps
from django.shortcuts import render
from django.http.response import HttpResponse
from django.views.generic import FormView
from django.core.mail import send_mail
from django.template.loader import render_to_string

from feedback.forms import FeedbackForm


class CreateFeedbackView(FormView):

    form_class = FeedbackForm

    def dispatch(self, request, *args, **kwargs):
        self.is_modal = request.GET.get('modal', False)
        return super().dispatch(request, *args, **kwargs)

    def get_initial(self):

        user = self.request.user

        if user.is_authenticated:
            return {
                'name': user.get_full_name(),
                'email': user.email
            }

        return self.initial

    @property
    def template_name(self):
        return 'feedback/modal.html' if self.is_modal else 'feedback/view.html'

    def form_valid(self, form):

        obj = form.save(commit=False)

        if self.request.user.is_authenticated:
            obj.user = self.request.user

        obj.save()

        self.send_email_notification(obj)
        self.send_sms_notification(obj)

        message = render_to_string(
            'feedback/success-message.html', {'object': obj})

        return HttpResponse(message)

    def form_invalid(self, form):
        return render(
            self.request,
            'feedback/form.html' if self.is_modal else 'feedback/view.html',
            {'form': form},
            status=403)

    def send_email_notification(self, obj):

        context = self.get_notifications_context(obj)

        subject = render_to_string('feedback/email/subject.txt', context)

        html = render_to_string('feedback/email/message.html', context)

        send_mail(
            subject=subject.strip(),
            message='',
            from_email=settings.DEFAULT_FROM_EMAIL,
            html_message=html,
            recipient_list=self.get_email_recipients())

    def get_email_recipients(self):
        return [a[1] for a in settings.MANAGERS]

    def send_sms_notification(self, obj):

        if not apps.is_installed('turbosms'):
            return

        from turbosms.lib import send_sms_from_template

        context = self.get_notifications_context(obj)

        send_sms_from_template('feedback/sms.txt', context)

    def get_notifications_context(self, obj):
        return {
            'object': obj,
            'site': apps.get_model('sites', 'Site').objects.get_current()
        }




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class FeedbackAppConfig(AppConfig):

    name = 'feedback'
    verbose_name = _('Feedback')


default_app_config = 'feedback.FeedbackAppConfig'
